==> map-0.21.jar: JoinTatemono.java <==
import java.awt.geom.*;
import java.util.*;

/*
 * : 2004/01/10
 */

/**
 * °ˤƥݥꥴ礹륯饹Ǥ
 * @author Kumano Tatsuo
 */
class JoinTatemono {

	private boolean isChanged;

	/**
	 * °ˤƥݥꥴ򸫤礷ޤ
	 * Υ᥽åɤƤӽФľ isChanged() ƤӽФȡ
	 * Υ᥽åɤˤäϿޤξ֤ѲɤǤޤ
	 * @param maps Ͽ
	 */
	void joinTatemono(Map maps) throws Exception {
		isChanged = false;
		Map attributePolygonMap = new HashMap(); // String -> Collection<Polygon>  Map
		// °򥭡ݥꥴνͤȤ Map 
		for (Iterator iter = maps.values().iterator(); iter.hasNext();) {
			MapData mapData = (MapData) iter.next();
			if (mapData.hasTatemono()) {
				for (Iterator iter2 = mapData.getTatemono().values().iterator(); iter2.hasNext();) {
					Polygon polygon = (Polygon) iter2.next();
					if (polygon.getAttribute() != null) {
						if (polygon.getAttribute().length() > 0) {
							if (!attributePolygonMap.containsKey(polygon.getAttribute())) {
								attributePolygonMap.put(polygon.getAttribute(), new ArrayList());
							}
							((Collection) attributePolygonMap.get(polygon.getAttribute())).add(polygon);
						}
					}
				}
			}
		}
		for (Iterator iter = attributePolygonMap.values().iterator(); iter.hasNext();) {
			Collection polygons = (Collection) iter.next();
			if (polygons.size() > 1) {
				GeneralPath path = new GeneralPath();
				for (Iterator iter2 = polygons.iterator(); iter2.hasNext();) {
					Polygon polygon = ((Polygon) iter2.next());
					path.append(polygon.getPath(), false);
					//System.out.print(polygon);
				}
				//System.out.println("Ʊ̾Ǥ");
				for (Iterator iter2 = polygons.iterator(); iter2.hasNext();) {
					Polygon polygon = ((Polygon) iter2.next());
					polygon.setX(path.getBounds().getCenterX());
					polygon.setY(path.getBounds().getCenterY());
				}
			}
		}
	}

	/**
	 * ľηǡϿޤξ֤Ѳɤޤ
	 * @return Ͽޤξ֤Ѳɤ
	 */
	boolean isChanged() {
		return isChanged;
	}

}

==> map-0.29.jar: JoinTatemono.java <==
import java.awt.geom.*;
import java.util.*;

/*
 * : 2004/01/10
 */

/**
 * °ˤƥݥꥴ礹륯饹Ǥ
 * @author Kumano Tatsuo
 */
class JoinTatemono {

	private boolean isChanged;

	/** °ˤƥݥꥴ򸫤礷ޤ
         * Υ᥽åɤƤӽФľ isChanged() ƤӽФȡ
         * Υ᥽åɤˤäϿޤξ֤ѲɤǤޤ
         * @param maps Ͽ
         * @throws Exception 㳰
         */
	void joinTatemono(Map maps) throws Exception {
		isChanged = false;
		Map attributePolygonMap = new HashMap(); // String -> Collection<Polygon>  Map
		// °򥭡ݥꥴνͤȤ Map 
		for (Iterator iter = maps.values().iterator(); iter.hasNext();) {
			MapData mapData = (MapData) iter.next();
			if (mapData.hasTatemono()) {
				for (Iterator iter2 = mapData.getTatemono().values().iterator(); iter2.hasNext();) {
					PolygonData polygon = (PolygonData) iter2.next();
					if (polygon.getAttribute() != null) {
						if (polygon.getAttribute().length() > 0) {
							if (!attributePolygonMap.containsKey(polygon.getAttribute())) {
								attributePolygonMap.put(polygon.getAttribute(), new ArrayList());
							}
							((Collection) attributePolygonMap.get(polygon.getAttribute())).add(polygon);
						}
					}
				}
			}
		}
		for (Iterator iter = attributePolygonMap.values().iterator(); iter.hasNext();) {
			Collection polygons = (Collection) iter.next();
			if (polygons.size() > 1) {
				Rectangle2D rect = null;
				for (Iterator iter2 = polygons.iterator(); iter2.hasNext();) {
					PolygonData polygon = ((PolygonData) iter2.next());
					if(rect == null){
						rect = polygon.getArea().getBounds();
					}else{
						rect.add(polygon.getArea().getBounds());
					}
				}
				for (Iterator iter2 = polygons.iterator(); iter2.hasNext();) {
					PolygonData polygon = ((PolygonData) iter2.next());
					polygon.setX(rect.getCenterX());
					polygon.setY(rect.getCenterY());
				}
			}
		}
	}

	/**
	 * ľηǡϿޤξ֤Ѳɤޤ
	 * @return Ͽޤξ֤Ѳɤ
	 */
	boolean isChanged() {
		return isChanged;
	}

}
